# remirepo spec file for php-aws-sdk3, from
#
# Fedora spec file for php-aws-sdk3
#
# Copyright (c) 2016-2019 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     aws
%global github_name      aws-sdk-php
%global github_version   3.111.0
%global github_commit    a31376012346118b2b88df6d2f0c185af71e3096

%global composer_vendor  aws
%global composer_project aws-sdk-php

# "php": ">=5.5"
%global php_min_ver 5.5
# "andrewsville/php-token-reflection": "^1.4"
%global tokenreflection_min_ver 1.4
%global tokenreflection_max_ver 2.0
# "aws/aws-php-sns-message-validator": "~1.0"
%global aws_sns_message_validator_min_ver 1.0
%global aws_sns_message_validator_max_ver 2.0
# "doctrine/cache": "~1.4"
#     NOTE: Min version not 1.4 because autoloader required
%global doctrine_cache_min_ver 1.4.1
%global doctrine_cache_max_ver 2.0
# "guzzlehttp/guzzle": "^5.3.3|^6.2.1"
%global guzzle_min_ver 5.3.3
%global guzzle_max_ver 7.0
# "guzzlehttp/promises": "~1.0"
%global guzzle_promises_min_ver 1.0
%global guzzle_promises_max_ver 2.0
# "guzzlehttp/psr7": "^1.4.1"
%global guzzle_psr7_min_ver 1.4.1
%global guzzle_psr7_max_ver 2.0
# "mtdowling/jmespath.php": "~2.2"
%global jmespath_min_ver 2.2
%global jmespath_max_ver 3.0
# "psr/cache": "^1.0"
%global psr_cache_min_ver 1.0
%global psr_cache_max_ver 2.0
# "psr/simple-cache": "^1.0"
%global psr_simple_cache_min_ver 1.0
%global psr_simple_cache_max_ver 2.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-aws-sdk3
Version:       %{github_version}
Release:       1%{?dist}
Summary:       Amazon Web Services framework for PHP

License:       ASL 2.0
URL:           http://aws.amazon.com/sdkforphp

# GitHub export does not include tests.
# Run php-aws-sdk3-get-source.sh to create full source.
Source0:       %{name}-%{github_version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Library version value and autoloader check
BuildRequires: php-cli
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(guzzlehttp/guzzle) >= %{guzzle_min_ver} with php-composer(guzzlehttp/guzzle) < %{guzzle_max_ver})
BuildRequires: (php-composer(guzzlehttp/promises) >= %{guzzle_promises_min_ver} with php-composer(guzzlehttp/promises) < %{guzzle_promises_max_ver})
BuildRequires: (php-composer(guzzlehttp/psr7) >= %{guzzle_psr7_min_ver} with php-composer(guzzlehttp/psr7) < %{guzzle_psr7_max_ver})
BuildRequires: (php-composer(mtdowling/jmespath.php) >= %{jmespath_min_ver} with php-composer(mtdowling/jmespath.php) < %{jmespath_max_ver})
%else
BuildRequires: php-composer(guzzlehttp/guzzle) <  %{guzzle_max_ver}
BuildRequires: php-composer(guzzlehttp/guzzle) >= 6
BuildRequires: php-composer(guzzlehttp/promises) <  %{guzzle_promises_max_ver}
BuildRequires: php-composer(guzzlehttp/promises) >= %{guzzle_promises_min_ver}
BuildRequires: php-composer(guzzlehttp/psr7) <  %{guzzle_psr7_max_ver}
BuildRequires: php-composer(guzzlehttp/psr7) >= %{guzzle_psr7_min_ver}
BuildRequires: php-composer(mtdowling/jmespath.php) <  %{jmespath_max_ver}
BuildRequires: php-composer(mtdowling/jmespath.php) >= %{jmespath_min_ver}
%endif
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
# Tests
%if %{with_tests}
## Classmap
BuildRequires: php-composer(theseer/autoload)
## composer.json
BuildRequires: php-composer(phpunit/phpunit)
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(andrewsville/php-token-reflection) >= %{tokenreflection_min_ver} with php-composer(andrewsville/php-token-reflection) < %{tokenreflection_max_ver})
BuildRequires: (php-composer(aws/aws-php-sns-message-validator) >= %{aws_sns_message_validator_min_ver} with php-composer(aws/aws-php-sns-message-validator) < %{aws_sns_message_validator_max_ver})
BuildRequires: (php-composer(doctrine/cache) >= %{doctrine_cache_min_ver} with php-composer(doctrine/cache) < %{doctrine_cache_max_ver})
BuildRequires: (php-composer(psr/cache) >= %{psr_cache_min_ver} with php-composer(psr/cache) < %{psr_cache_max_ver})
BuildRequires: (php-composer(psr/simple-cache) >= %{psr_simple_cache_min_ver} with php-composer(psr/simple-cache) < %{psr_simple_cache_max_ver})
%else
BuildRequires: php-composer(andrewsville/php-token-reflection) <  %{tokenreflection_max_ver}
BuildRequires: php-composer(andrewsville/php-token-reflection) >= %{tokenreflection_min_ver}
BuildRequires: php-composer(aws/aws-php-sns-message-validator) <  %{aws_sns_message_validator_max_ver}
BuildRequires: php-composer(aws/aws-php-sns-message-validator) >= %{aws_sns_message_validator_min_ver}
BuildRequires: php-composer(doctrine/cache) <  %{doctrine_cache_max_ver}
BuildRequires: php-composer(doctrine/cache) >= %{doctrine_cache_min_ver}
BuildRequires: php-composer(psr/cache) <  %{psr_cache_max_ver}
BuildRequires: php-composer(psr/cache) >= %{psr_cache_min_ver}
BuildRequires: php-composer(psr/simple-cache) <  %{psr_simple_cache_max_ver}
BuildRequires: php-composer(psr/simple-cache) >= %{psr_simple_cache_min_ver}
%endif
BuildRequires: php-dom
BuildRequires: php-json
BuildRequires: php-openssl
BuildRequires: php-pcntl
BuildRequires: php-pcre
BuildRequires: php-simplexml
BuildRequires: php-sockets
## phpcompatinfo (computed from version 3.87.15)
BuildRequires: php-curl
BuildRequires: php-date
BuildRequires: php-filter
BuildRequires: php-hash
BuildRequires: php-iconv
BuildRequires: php-libxml
BuildRequires: php-mbstring
BuildRequires: php-posix
BuildRequires: php-reflection
BuildRequires: php-session
BuildRequires: php-spl
BuildRequires: php-xml
BuildRequires: php-xmlwriter
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(guzzlehttp/guzzle) >= %{guzzle_min_ver} with php-composer(guzzlehttp/guzzle) < %{guzzle_max_ver})
Requires:      (php-composer(guzzlehttp/promises) >= %{guzzle_promises_min_ver} with php-composer(guzzlehttp/promises) < %{guzzle_promises_max_ver})
Requires:      (php-composer(guzzlehttp/psr7) >= %{guzzle_psr7_min_ver} with php-composer(guzzlehttp/psr7) < %{guzzle_psr7_max_ver})
Requires:      (php-composer(mtdowling/jmespath.php) >= %{jmespath_min_ver} with php-composer(mtdowling/jmespath.php) < %{jmespath_max_ver})
%else
Requires:      php-composer(guzzlehttp/guzzle) <  %{guzzle_max_ver}
Requires:      php-composer(guzzlehttp/guzzle) >= %{guzzle_min_ver}
Requires:      php-composer(guzzlehttp/promises) <  %{guzzle_promises_max_ver}
Requires:      php-composer(guzzlehttp/promises) >= %{guzzle_promises_min_ver}
Requires:      php-composer(guzzlehttp/psr7) <  %{guzzle_psr7_max_ver}
Requires:      php-composer(guzzlehttp/psr7) >= %{guzzle_psr7_min_ver}
Requires:      php-composer(mtdowling/jmespath.php) <  %{jmespath_max_ver}
Requires:      php-composer(mtdowling/jmespath.php) >= %{jmespath_min_ver}
%endif
Requires:      php-json
Requires:      php-pcre
Requires:      php-simplexml
# phpcompatinfo (computed from version 3.87.15)
Requires:      php-date
Requires:      php-filter
Requires:      php-hash
Requires:      php-iconv
Requires:      php-libxml
Requires:      php-mbstring
Requires:      php-reflection
Requires:      php-session
Requires:      php-spl
Requires:      php-xmlwriter
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Weak dependencies
## composer.json: optional
%if 0%{?fedora} >= 21 || 0%{?rhel} >= 8
Suggests:      php-curl
Suggests:      php-openssl
Suggests:      php-sockets
Suggests:      php-composer(doctrine/cache)
Suggests:      php-composer(aws/aws-php-sns-message-validator)
%endif

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
The AWS SDK for PHP makes it easy for developers to access Amazon Web
Services [1] in their PHP code, and build robust applications and software
using services like Amazon S3, Amazon DynamoDB, Amazon Glacier, etc.

Autoloader: %{phpdir}/Aws3/autoload.php

[1] http://aws.amazon.com/


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create autoloader
cat <<'AUTOLOAD' | tee src/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Aws\\', __DIR__);

\Fedora\Autoloader\Dependencies::required([
    __DIR__.'/functions.php',
    [
        '%{phpdir}/GuzzleHttp6/autoload.php',
        '%{phpdir}/GuzzleHttp/autoload.php',
    ],
    '%{phpdir}/GuzzleHttp/Promise/autoload.php',
    '%{phpdir}/GuzzleHttp/Psr7/autoload.php',
    '%{phpdir}/JmesPath/autoload.php',
]);

\Fedora\Autoloader\Dependencies::optional([
    '%{phpdir}/Aws/Sns/autoload.php',
    '%{phpdir}/Doctrine/Common/Cache/autoload.php',
]);
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}/Aws3
cp -pr src/* %{buildroot}%{phpdir}/Aws3/


%check
: Library version value and autoloader check
%{_bindir}/php -r '
    require_once "%{buildroot}%{phpdir}/Aws3/autoload.php";
    $version = \Aws\Sdk::VERSION;
    echo "Version $version (expected %{version})\n";
    exit(version_compare("%{version}", "$version", "=") ? 0 : 1);
'

%if %{with_tests}
: Create tests classmap
%{_bindir}/phpab --nolower --output bootstrap.classmap.php build/

: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
error_reporting(-1);
date_default_timezone_set('UTC');

require_once '%{buildroot}%{phpdir}/Aws3/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Aws\\Test\\', __DIR__.'/tests');
\Fedora\Autoloader\Autoload::addPsr4('TokenReflection\\', '%{phpdir}/TokenReflection');

\Fedora\Autoloader\Dependencies::required([
    __DIR__.'/bootstrap.classmap.php',
    '%{phpdir}/Psr/Cache/autoload.php',
    '%{phpdir}/Psr/SimpleCache/autoload.php',
]);

class_alias('PHPUnit_Framework_Error_Warning', 'PHPUnit\\Framework\\Error\\Warning');
class_alias('PHPUnit_Framework_Constraint_Callback', 'PHPUnit\\Framework\\Constraint\\Callback');
BOOTSTRAP

: Skip tests known to fail
sed 's/function testValidatesInput/function SKIP_testValidatesInput/' \
    -i tests/Api/ValidatorTest.php
sed -e 's/function testUserAgentAlwaysStartsWithSdkAgentString/function SKIP_testUserAgentAlwaysStartsWithSdkAgentString/' \
    -e 's/function testValidatesCallables/function SKIP_testValidatesCallables/' \
    -e 's/function testValidatesInput/function SKIP_testValidatesInput/' \
    -i tests/ClientResolverTest.php
sed 's/function testEmitsDebugInfo/function SKIP_testEmitsDebugInfo/' \
    -i tests/TraceMiddlewareTest.php
sed -e 's/function testTracksAwsSpecificExceptions/function SKIP_testTracksAwsSpecificExceptions/' \
    -e 's/function testTracksExceptions/function SKIP_testTracksExceptions/' \
    -i tests/TraceMiddlewareTest.php
rm -f \
    tests/Integ/GuzzleV5HandlerTest.php \
    tests/Integ/GuzzleV6StreamHandlerTest.php

: Skip tests that include 64-bit format codes on 32-bit PHP
if [ $(php -r 'echo PHP_INT_SIZE === 4 ? 32 : 64;') == 32 ]
then
    sed -e 's/function testPassesComplianceTest/function SKIP_testPassesComplianceTest/' \
        -e 's/function testEmitsEvents/function SKIP_testEmitsEvents/' \
        -e 's/function testThrowsOnUnknownEventType/function SKIP_testThrowsOnUnknownEventType/' \
        -i tests/Api/Parser/DecodingEventStreamIteratorTest.php
    sed -e 's/function testEmitsEvents/function SKIP_testEmitsEvents/' \
        -e 's/function testThrowsOnUnknownEventType/function SKIP_testThrowsOnUnknownEventType/' \
        -i tests/Api/Parser/EventParsingIteratorTest.php
fi

%if 0%{?rhel} == 6
sed -e 's/testsAddsDefaultCurlOptions/SKIP_testsAddsDefaultCurlOptions/' \
    -i tests/Lambda/LambdaClientTest.php
%endif

export AWS_ACCESS_KEY_ID=foo
export AWS_SECRET_ACCESS_KEY=bar

: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
# TODO 7.4 PHP Fatal error:  Method GuzzleHttp\Psr7\CachingStream::__toString() must not throw an exception
for PHP_EXEC in "" php71 php72 php73; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT -d memory_limit=1G --verbose  --testsuite=unit \
            --bootstrap bootstrap.php || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE.md
%doc CHANGELOG.md
%doc composer.json
%doc README.md
%doc UPGRADING.md
%{phpdir}/Aws3


%changelog
* Mon Sep 09 2019 Shawn Iwinski <shawn@iwin.ski> - 3.111.0-1
- Update to 3.111.0 (RHBZ #1714768)

* Fri May 24 2019 Shawn Iwinski <shawn@iwin.ski> - 3.95.0-1
- Update to 3.95.0 (RHBZ #1695281)

* Mon Apr 01 2019 Shawn Iwinski <shawn@iwin.ski> - 3.91.0-1
- Update to 3.91.0 (RHBZ #1680149)

* Thu Feb 21 2019 Shawn Iwinski <shawn@iwin.ski> - 3.87.15-1
- Update to 3.87.15 (RHBZ #1599469)
- Remove php-composer(nette/neon) dependency

* Sat Jul 07 2018 Shawn Iwinski <shawn@iwin.ski> - 3.62.10-1
- Update to 3.62.10 (RHBZ #1563020)

* Sat Mar 31 2018 Shawn Iwinski <shawn@iwin.ski> - 3.53.0-1
- Update to 3.53.0 (RHBZ #1525280)
- Add range version dependencies for Fedora >= 27 || RHEL >= 8

* Mon Dec 11 2017 Shawn Iwinski <shawn@iwin.ski> - 3.46.0-1
- Update to 3.46.0 (RHBZ #1503361)

* Thu Oct 05 2017 Shawn Iwinski <shawn@iwin.ski> - 3.36.20-1
- Update to 3.36.20 (RHBZ #1484590)

* Tue Aug 22 2017 Shawn Iwinski <shawn@iwin.ski> - 3.34.0-1
- Update to 3.34.0 (RHBZ #1476044)

* Thu Jul 27 2017 Shawn Iwinski <shawn@iwin.ski> - 3.32.0-1
- Update to 3.32.0 (RHBZ #1472012)
- Remove patch to fix PHP 7.2 failures

* Mon Jul 17 2017 Shawn Iwinski <shawn@iwin.ski> - 3.31.5-1
- Updated to 3.31.5 (RHBZ #1468058)

* Sun Jul 02 2017 Shawn Iwinski <shawn@iwin.ski> - 3.31.0-1
- Updated to 3.31.0 (RHBZ #1464279)

* Fri Jun 30 2017 Remi Collet <remi@remirepo.net> - 3.30.4-1
- Update to 3.30.4

* Thu Jun 29 2017 Remi Collet <remi@remirepo.net> - 3.30.3-1
- Update to 3.30.3

* Mon Jun 26 2017 Remi Collet <remi@remirepo.net> - 3.30.2-1
- Update to 3.30.2

* Sat Jun 24 2017 Shawn Iwinski <shawn@iwin.ski> - 3.30.0-2
- Add patch to fix PHP 7.2 failures
- Add php72 to SCL tests
- Add max versions to some additional BuildRequires dependencies

* Wed Jun 21 2017 Shawn Iwinski <shawn@iwin.ski> - 3.30.0-1
- Updated to 3.30.0 (RHBZ #1449422)

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 3.29.9-1
- Update to 3.29.9

* Tue Jun 20 2017 Remi Collet <remi@remirepo.net> - 3.29.8-1
- Update to 3.29.8

* Mon Jun 19 2017 Remi Collet <remi@remirepo.net> - 3.29.7-1
- Update to 3.29.7

* Fri Jun 16 2017 Remi Collet <remi@remirepo.net> - 3.29.6-1
- Update to 3.29.6

* Thu Jun 15 2017 Remi Collet <remi@remirepo.net> - 3.29.5-1
- Update to 3.29.5

* Wed Jun 14 2017 Remi Collet <remi@remirepo.net> - 3.29.4-1
- Update to 3.29.4

* Tue Jun 13 2017 Remi Collet <remi@remirepo.net> - 3.29.3-1
- Update to 3.29.3

* Sun Jun 11 2017 Remi Collet <remi@remirepo.net> - 3.29.2-1
- Update to 3.29.2

* Fri Jun  9 2017 Remi Collet <remi@remirepo.net> - 3.29.0-1
- Update to 3.29.0

* Wed Jun  7 2017 Remi Collet <remi@remirepo.net> - 3.28.10-1
- Update to 3.28.10

* Mon Jun  5 2017 Remi Collet <remi@remirepo.net> - 3.28.8-1
- Update to 3.28.8

* Fri Jun  2 2017 Remi Collet <remi@remirepo.net> - 3.28.7-1
- Update to 3.28.7

* Thu Jun  1 2017 Remi Collet <remi@remirepo.net> - 3.28.6-1
- Update to 3.28.6

* Wed May 31 2017 Remi Collet <remi@remirepo.net> - 3.28.5-1
- Update to 3.28.5

* Sat May 27 2017 Remi Collet <remi@remirepo.net> - 3.28.4-1
- Update to 3.28.4
- open https://github.com/aws/aws-sdk-php/pull/1298 - PHP 7.2

* Wed May 24 2017 Remi Collet <remi@remirepo.net> - 3.28.2-1
- Update to 3.28.2

* Tue May 23 2017 Remi Collet <remi@remirepo.net> - 3.28.1-1
- Update to 3.28.1

* Mon May 22 2017 Remi Collet <remi@remirepo.net> - 3.28.0-1
- Update to 3.28.0

* Wed May 17 2017 Remi Collet <remi@remirepo.net> - 3.27.4-1
- Update to 3.27.4

* Tue May 16 2017 Remi Collet <remi@remirepo.net> - 3.27.3-1
- Update to 3.27.3

* Fri May 12 2017 Remi Collet <remi@remirepo.net> - 3.27.2-1
- Update to 3.27.2

* Wed May 10 2017 Remi Collet <remi@remirepo.net> - 3.27.1-1
- Update to 3.27.1

* Fri May  5 2017 Remi Collet <remi@remirepo.net> - 3.27.0-1
- Update to 3.27.0

* Sat Apr 29 2017 Remi Collet <remi@remirepo.net> - 3.26.5-1
- Update to 3.26.5

* Thu Apr 27 2017 Remi Collet <remi@remirepo.net> - 3.26.3-1
- Update to 3.26.3

* Mon Apr 24 2017 Remi Collet <remi@remirepo.net> - 3.26.2-1
- Update to 3.26.2

* Fri Apr 21 2017 Remi Collet <remi@remirepo.net> - 3.26.1-1
- Update to 3.26.1

* Thu Apr 20 2017 Shawn Iwinski <shawn@iwin.ski> - 3.26.0-1
- Updated to 3.26.0 (RHBZ #1438105)

* Wed Apr 12 2017 Remi Collet <remi@remirepo.net> - 3.25.7-1
- Update to 3.25.7

* Mon Apr 10 2017 Remi Collet <remi@remirepo.net> - 3.25.6-1
- Update to 3.25.6

* Fri Apr  7 2017 Remi Collet <remi@remirepo.net> - 3.25.5-1
- Update to 3.25.5

* Thu Apr  6 2017 Remi Collet <remi@remirepo.net> - 3.25.4-1
- Update to 3.25.4

* Wed Apr  5 2017 Remi Collet <remi@remirepo.net> - 3.25.3-1
- Update to 3.25.3

* Tue Apr  4 2017 Remi Collet <remi@remirepo.net> - 3.25.2-1
- Update to 3.25.2

* Sat Apr  1 2017 Remi Collet <remi@remirepo.net> - 3.25.1-1
- Update to 3.25.1

* Fri Mar 31 2017 Shawn Iwinski <shawn@iwin.ski> - 3.25.0-1
- Updated to 3.25.0 (RHBZ #1431302)

* Fri Mar 31 2017 Remi Collet <remi@remirepo.net> - 3.25.0-1
- Update to 3.25.0

* Wed Mar 29 2017 Remi Collet <remi@remirepo.net> - 3.24.9-1
- Update to 3.24.9

* Tue Mar 28 2017 Remi Collet <remi@remirepo.net> - 3.24.8-1
- Update to 3.24.8

* Fri Mar 24 2017 Remi Collet <remi@remirepo.net> - 3.24.7-1
- Update to 3.24.7

* Thu Mar 23 2017 Remi Collet <remi@remirepo.net> - 3.24.6-1
- Update to 3.24.6

* Wed Mar 22 2017 Remi Collet <remi@remirepo.net> - 3.24.5-1
- Update to 3.24.5

* Tue Mar 14 2017 Remi Collet <remi@remirepo.net> - 3.24.4-1
- Update to 3.24.4

* Sat Mar 11 2017 Remi Collet <remi@remirepo.net> - 3.24.2-1
- Update to 3.24.2

* Fri Mar 10 2017 Shawn Iwinski <shawn@iwin.ski> - 3.24.1-1
- Updated to 3.24.1 (RHBZ #1415013)
- Added max versions to BuildRequires
- Removed conflicts for weak dependencies' version constraints

* Fri Mar 10 2017 Remi Collet <remi@remirepo.net> - 3.24.1-1
- Update to 3.24.1

* Thu Mar  9 2017 Remi Collet <remi@remirepo.net> - 3.24.0-1
- Update to 3.24.0

* Wed Mar  8 2017 Remi Collet <remi@remirepo.net> - 3.23.3-1
- Update to 3.23.3

* Tue Mar  7 2017 Remi Collet <remi@remirepo.net> - 3.23.2-1
- Update to 3.23.2

* Tue Feb 28 2017 Remi Collet <remi@remirepo.net> - 3.23.1-1
- update to 3.23.1

* Sun Feb 26 2017 Remi Collet <remi@remirepo.net> - 3.22.11-1
- update to 3.22.11

* Fri Feb 24 2017 Remi Collet <remi@remirepo.net> - 3.22.10-1
- update to 3.22.10

* Thu Feb 23 2017 Remi Collet <remi@remirepo.net> - 3.22.9-1
- update to 3.22.9

* Wed Feb 22 2017 Remi Collet <remi@remirepo.net> - 3.22.8-1
- update to 3.22.8

* Sat Feb 18 2017 Remi Collet <remi@remirepo.net> - 3.22.7-1
- update to 3.22.7

* Fri Feb 17 2017 Remi Collet <remi@remirepo.net> - 3.22.6-1
- update to 3.22.6

* Thu Feb 16 2017 Remi Collet <remi@remirepo.net> - 3.22.5-1
- update to 3.22.5

* Wed Feb 15 2017 Remi Collet <remi@remirepo.net> - 3.22.4-1
- update to 3.22.4

* Sat Feb 11 2017 Remi Collet <remi@remirepo.net> - 3.22.3-1
- update to 3.22.3

* Fri Feb 10 2017 Remi Collet <remi@remirepo.net> - 3.22.1-1
- update to 3.22.1

* Wed Feb  8 2017 Remi Collet <remi@remirepo.net> - 3.22.0-1
- update to 3.22.0

* Fri Jan 27 2017 Remi Collet <remi@remirepo.net> - 3.21.6-1
- update to 3.21.6

* Thu Jan 26 2017 Remi Collet <remi@remirepo.net> - 3.21.5-1
- update to 3.21.5

* Wed Jan 25 2017 Remi Collet <remi@remirepo.net> - 3.21.4-1
- update to 3.21.4

* Sat Jan 21 2017 Remi Collet <remi@remirepo.net> - 3.21.3-1
- update to 3.21.3

* Fri Jan 20 2017 Remi Collet <remi@remirepo.net> - 3.21.2-1
- update to 3.21.2

* Thu Jan 19 2017 Remi Collet <remi@remirepo.net> - 3.21.1-1
- update to 3.21.1

* Wed Jan 18 2017 Shawn Iwinski <shawn@iwin.ski> - 3.21.0-1
- Updated to 3.21.0 (RHBZ #1405254)

* Tue Jan 17 2017 Remi Collet <remi@remirepo.net> - 3.20.16-1
- update to 3.20.16

* Thu Jan  5 2017 Remi Collet <remi@remirepo.net> - 3.20.13-1
- update to 3.20.13

* Fri Dec 30 2016 Remi Collet <remi@remirepo.net> - 3.20.12-1
- update to 3.20.12

* Mon Dec 26 2016 Shawn Iwinski <shawn@iwin.ski> - 3.20.11-1
- Updated to 3.20.11 (RHBZ #1405254)
- Run upstream tests with SCLs if they are available

* Fri Dec 23 2016 Remi Collet <remi@remirepo.net> - 3.20.11-1
- update to 3.20.11

* Thu Dec 22 2016 Remi Collet <remi@remirepo.net> - 3.20.10-1
- update to 3.20.10

* Wed Dec 21 2016 Remi Collet <remi@remirepo.net> - 3.20.9-1
- update to 3.20.9

* Tue Dec 20 2016 Remi Collet <remi@remirepo.net> - 3.20.8-1
- update to 3.20.8

* Fri Dec 16 2016 Remi Collet <remi@remirepo.net> - 3.20.7-1
- update to 3.20.7

* Thu Dec 15 2016 Shawn Iwinski <shawn@iwin.ski> - 3.20.6-1
- Updated to 3.20.6 (RHBZ #1402170)

* Tue Dec 13 2016 Remi Collet <remi@remirepo.net> - 3.20.5-1
- update to 3.20.5

* Fri Dec  9 2016 Remi Collet <remi@remirepo.net> - 3.20.4-1
- update to 3.20.4

* Thu Dec  8 2016 Remi Collet <remi@remirepo.net> - 3.20.3-1
- update to 3.20.3

* Wed Dec  7 2016 Remi Collet <remi@remirepo.net> - 3.20.2-1
- update to 3.20.2

* Fri Dec  2 2016 Remi Collet <remi@remirepo.net> - 3.20.1-1
- update to 3.20.1

* Thu Dec 01 2016 Shawn Iwinski <shawn@iwin.ski> - 3.20.0-1
- Updated to 3.20.0 (RHBZ #1397218)

* Wed Nov 30 2016 Remi Collet <remi@remirepo.net> - 3.19.33-1
- update to 3.19.33

* Wed Nov 23 2016 Remi Collet <remi@remirepo.net> - 3.19.32-1
- update to 3.19.32

* Tue Nov 22 2016 Remi Collet <remi@remirepo.net> - 3.19.31-1
- update to 3.19.31

* Mon Nov 21 2016 Shawn Iwinski <shawn@iwin.ski> - 3.19.30-1
- Updated to 3.19.30 (RHBZ #1380046)
- Switched autoloader from php-composer(symfony/class-loader) to
  php-composer(fedora/autoloader)

* Fri Nov 18 2016 Remi Collet <remi@remirepo.net> - 3.19.28-1
- update to 3.19.28

* Thu Nov 17 2016 Remi Collet <remi@remirepo.net> - 3.19.27-1
- update to 3.19.27

* Wed Nov 16 2016 Remi Collet <remi@remirepo.net> - 3.19.26-1
- update to 3.19.26

* Tue Nov 15 2016 Remi Collet <remi@remirepo.net> - 3.19.25-1
- update to 3.19.25

* Fri Nov 11 2016 Remi Collet <remi@remirepo.net> - 3.19.24-1
- update to 3.19.24

* Fri Nov  4 2016 Remi Collet <remi@remirepo.net> - 3.19.23-1
- update to 3.19.23

* Thu Nov  3 2016 Remi Collet <remi@remirepo.net> - 3.19.22-1
- update to 3.19.22

* Wed Nov  2 2016 Remi Collet <remi@remirepo.net> - 3.19.21-1
- update to 3.19.21

* Wed Oct 26 2016 Remi Collet <remi@remirepo.net> - 3.19.20-1
- update to 3.19.20

* Tue Oct 25 2016 Remi Collet <remi@remirepo.net> - 3.19.19-1
- update to 3.19.19

* Fri Oct 21 2016 Remi Collet <remi@remirepo.net> - 3.19.18-1
- update to 3.19.18

* Wed Oct 19 2016 Remi Collet <remi@remirepo.net> - 3.19.17-1
- update to 3.19.17

* Tue Oct 18 2016 Remi Collet <remi@remirepo.net> - 3.19.16-1
- update to 3.19.16

* Fri Oct 14 2016 Remi Collet <remi@remirepo.net> - 3.19.15-1
- update to 3.19.15

* Thu Oct 13 2016 Remi Collet <remi@remirepo.net> - 3.19.14-1
- update to 3.19.14

* Fri Oct  7 2016 Remi Collet <remi@remirepo.net> - 3.19.13-1
- update to 3.19.13

* Fri Sep 30 2016 Remi Collet <remi@remirepo.net> - 3.19.12-1
- update to 3.19.12

* Wed Sep 28 2016 Remi Collet <remi@remirepo.net> - 3.19.11-1
- update to 3.19.11

* Sun Sep 25 2016 Shawn Iwinski <shawn@iwin.ski> - 3.19.10-1
- Updated to 3.19.10 (RHBZ #1376241)

* Fri Sep 23 2016 Remi Collet <remi@remirepo.net> - 3.19.10-1
- update to 3.19.10

* Mon Sep 19 2016 Remi Collet <remi@remirepo.net> - 3.19.8-1
- update to 3.19.8

* Wed Sep 14 2016 Remi Collet <remi@remirepo.net> - 3.19.7-1
- update to 3.19.7

* Sun Sep 11 2016 Shawn Iwinski <shawn@iwin.ski> - 3.19.6-1
- Updated to 3.19.6 (RHBZ #1365099)

* Fri Aug 12 2016 Remi Collet <remi@remirepo.net> - 3.18.39-1
- update to 3.18.39

* Wed Aug 10 2016 Remi Collet <remi@remirepo.net> - 3.18.38-1
- update to 3.18.38

* Fri Aug  5 2016 Remi Collet <remi@remirepo.net> - 3.18.37-1
- update to 3.18.37

* Wed Aug  3 2016 Remi Collet <remi@remirepo.net> - 3.18.36-1
- update to 3.18.36

* Fri Jul 29 2016 Remi Collet <remi@remirepo.net> - 3.18.35-1
- update to 3.18.35

* Thu Jul 21 2016 Remi Collet <remi@remirepo.net> - 3.18.31-1
- update to 3.18.31

* Sun Jul 17 2016 Remi Collet <remi@remirepo.net> - 3.18.28-1
- update to 3.18.28

* Fri Jul  8 2016 Remi Collet <remi@remirepo.net> - 3.18.27-1
- update to 3.18.27

* Wed Jul  6 2016 Remi Collet <remi@remirepo.net> - 3.18.25-1
- update to 3.18.25

* Mon Jul 04 2016 Shawn Iwinski <shawn@iwin.ski> - 3.18.24-1
- Updated to 3.18.24 (RHBZ #1342771)

* Sat Jul  2 2016 Remi Collet <remi@remirepo.net> - 3.18.24-1
- update to 3.18.24

* Fri Jul  1 2016 Remi Collet <remi@remirepo.net> - 3.18.23-1
- update to 3.18.23

* Thu Jun 30 2016 Remi Collet <remi@remirepo.net> - 3.18.22-1
- update to 3.18.22

* Tue Jun 28 2016 Remi Collet <remi@remirepo.net> - 3.18.21-1
- update to 3.18.21

* Fri Jun 24 2016 Remi Collet <remi@remirepo.net> - 3.18.20-1
- update to 3.18.20

* Wed Jun 22 2016 Remi Collet <remi@remirepo.net> - 3.18.19-1
- update to 3.18.19

* Wed Jun 15 2016 Remi Collet <remi@remirepo.net> - 3.18.18-1
- update to 3.18.18

* Fri Jun 10 2016 Remi Collet <remi@remirepo.net> - 3.18.17-1
- update to 3.18.17

* Fri Jun  3 2016 Remi Collet <remi@remirepo.net> - 3.18.15-1
- update to 3.18.15

* Fri May 27 2016 Remi Collet <remi@remirepo.net> - 3.18.14-1
- update to 3.18.14

* Wed May 25 2016 Remi Collet <remi@remirepo.net> - 3.18.13-1
- update to 3.18.13

* Fri May 20 2016 Remi Collet <remi@remirepo.net> - 3.18.12-1
- update to 3.18.12

* Fri May 20 2016 Remi Collet <remi@remirepo.net> - 3.18.11-1
- update to 3.18.11

* Wed May 18 2016 Remi Collet <remi@remirepo.net> - 3.18.9-1
- update to 3.18.9

* Fri May  6 2016 Remi Collet <remi@remirepo.net> - 3.18.6-1
- update to 3.18.6

* Wed May  4 2016 Remi Collet <remi@remirepo.net> - 3.18.5-1
- update to 3.18.5

* Fri Apr 29 2016 Remi Collet <remi@remirepo.net> - 3.18.4-1
- update to 3.18.4

* Thu Apr 28 2016 Remi Collet <remi@remirepo.net> - 3.18.3-1
- update to 3.18.3

* Fri Apr 22 2016 Remi Collet <remi@remirepo.net> - 3.18.1-1
- update to 3.18.1

* Thu Apr 21 2016 Remi Collet <remi@remirepo.net> - 3.18.0-1
- backport for remi repository

* Wed Apr 20 2016 Shawn Iwinski <shawn@iwin.ski> - 3.18.0-1
- Updated to 3.18.0
- Modified autoloader to not use @include_once for optional dependencies
- Set test memory_limit because build issues on certain systems

* Tue Apr 12 2016 Shawn Iwinski <shawn@iwin.ski> - 3.17.6-1
- Initial package
